@@ -45,11 +45,24 @@ for i in ${extensions}; do
 	echo -n .
 done
 
+"${ZCAT}" in > copy || fail=1
+cmp in copy || fail=1
+echo -n .
 "${ZCAT}" in in.gz in.bz2 in.lz -- -in- > copy5 || fail=1
 cmp in5 copy5 || fail=1
 echo -n .
 
 
+for i in ${extensions}; do
+	"${ZDIFF}" --cmp in.$i || fail=1
+	echo -n .
+	"${ZDIFF}" --cmp in in.$i || fail=1
+	echo -n .
+	"${ZDIFF}" --cmp in.$i in || fail=1
+	echo -n .
+done
+
+
 for i in ${extensions}; do
 	"${ZDIFF}" in.$i || fail=1
 	echo -n .
@@ -81,27 +94,23 @@ echo -n .
 echo -n .
 
 
-for i in ${extensions}; do
-	"${ZDIFF}" --cmp in.$i || fail=1
-	echo -n .
-	"${ZDIFF}" --cmp in in.$i || fail=1
-	echo -n .
-	"${ZDIFF}" --cmp in.$i in || fail=1
-	echo -n .
-done
-
-
 for i in ${extensions}; do
 	"${ZGREP}" License in.$i 2>&1 > /dev/null || fail=1
 	echo -n .
 done
 
+"${ZGREP}" License in 2>&1 > /dev/null || fail=1
+echo -n .
+"${ZGREP}" License -- -in- 2>&1 > /dev/null || fail=1
+echo -n .
+"${ZGREP}" License -- -in-.lz 2>&1 > /dev/null || fail=1
+echo -n .
 "${ZGREP}" License in in.gz in.bz2 in.lz -- -in- 2>&1 > /dev/null || fail=1
 echo -n .
 
 
 echo
-if test ${fail} = 0; then
+if [ ${fail} = 0 ]; then
 	echo "tests completed successfully."
 	cd "${objdir}" && rm -r tmp
 else
